# Native Convert

[Gimpformats Index](../README.md#gimpformats-index) / [Gimpformats](./index.md#gimpformats) / Native Convert

> Auto-generated documentation for [gimpformats.native_convert](../../../gimpformats/native_convert.py) module.

- [Native Convert](#native-convert)
  - [convert_xcf_to_flat_image](#convert_xcf_to_flat_image)

## convert_xcf_to_flat_image

[Show source in native_convert.py:45](../../../gimpformats/native_convert.py#L45)

#### Signature

```python
def convert_xcf_to_flat_image(xcf_path: str, output_path: str) -> None: ...
```